/* SPDX-FileCopyrightText: 2014-2015 - Sébastien Wilmet
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#pragma once

#include <glib.h>

G_BEGIN_DECLS

/* This header permits to avoid problems with header #includes cycles. For
 * example when type-a.h needs the TypeB declaration, and type-b.h needs the
 * TypeA declaration.
 *
 * TODO: move a maximum of types to their respective header. To make it easier
 * to copy a class outside the project.
 * (in the past every type was added here, now it should be done only when
 * really necessary).
 */

typedef struct _GtexBuildJob                GtexBuildJob;
typedef struct _GtexBuildTool               GtexBuildTool;
typedef struct _GtexBuildTools              GtexBuildTools;
typedef struct _GtexBuildToolsDefault       GtexBuildToolsDefault;
typedef struct _GtexBuildToolsPersonal      GtexBuildToolsPersonal;
typedef struct _GtexBuildView               GtexBuildView;
typedef struct _GtexPostProcessor           GtexPostProcessor;
typedef struct _GtexPostProcessorAllOutput  GtexPostProcessorAllOutput;
typedef struct _GtexPostProcessorLatex      GtexPostProcessorLatex;
typedef struct _GtexPostProcessorLatexmk    GtexPostProcessorLatexmk;
typedef struct _GtexTemplatesDefault        GtexTemplatesDefault;
typedef struct _GtexTemplatesPersonal       GtexTemplatesPersonal;

G_END_DECLS
