/* SPDX-FileCopyrightText: 2022 - Sébastien Wilmet
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#pragma once

#include <gtk/gtk.h>

G_BEGIN_DECLS

GtkNotebook *	gtex_prefs_create_notebook	(void);

G_END_DECLS
