/* SPDX-FileCopyrightText: 2020 - Sébastien Wilmet
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#pragma once

#include <tepl/tepl.h>

G_BEGIN_DECLS

void	gtex_buffer_setup	(TeplBuffer *buffer);

G_END_DECLS
