/* SPDX-FileCopyrightText: 2014-2022 - Sébastien Wilmet
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#pragma once

#include <gtk/gtk.h>

G_BEGIN_DECLS

void		gtex_utils_show_uri		(GtkWidget    *widget,
						 const gchar  *uri,
						 guint32       timestamp,
						 GError      **error);

GtkWidget *	gtex_utils_get_dialog_component	(const gchar *title,
						 GtkWidget   *widget);

void		gtex_utils_migrate_settings	(void);

G_END_DECLS
