/* SPDX-FileCopyrightText: 2017-2020 - Sébastien Wilmet
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#pragma once

#include <tepl/tepl.h>

G_BEGIN_DECLS

void		gtex_latex_commands_add_action_infos	(GtkApplication *gtk_app);

void		gtex_latex_commands_add_actions		(GtkApplicationWindow *gtk_window);

GtkToolbar *	gtex_latex_commands_create_edit_toolbar	(GtkApplicationWindow *gtk_window);

GtkMenu *	gtex_latex_commands_create_latex_menu	(GtkApplicationWindow *gtk_window);

GtkMenu *	gtex_latex_commands_create_math_menu	(GtkApplicationWindow *gtk_window);

G_END_DECLS
